[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
[![PYPI][pypi-shield]][pypi-url]
[![PyVersion][pyversion-shield]][pyversion-url]
[![Conda][conda-shield]][conda-url]
[![ghcr.io][ghcrio-shield]][ghcrio-url]

# Pycashier

Tool for extracting and processing DNA barcode tags from Illumina sequencing.

Default parameters are designed for use by the [Brock Lab](https://github.com/brocklab) to process data generated from
[ClonMapper](https://docs.brocklab.com/clonmapper) lineage tracing experiments, but is extensible to other similarly designed tools.

See the [documentation](https://docs.brocklab.com/pycashier) for installation and usage instructions.

[conda-shield]: https://img.shields.io/conda/vn/conda-forge/pycashier
[conda-url]: https://anaconda.org/conda-forge/pycashier
[pypi-shield]: https://img.shields.io/pypi/v/pycashier
[pypi-url]: https://pypi.org/project/pycashier/
[pyversion-url]: https://pypi.org/project/pycashier/
[pyversion-shield]: https://img.shields.io/badge/dynamic/json?query=info.requires_python&label=python&url=https%3A%2F%2Fpypi.org%2Fpypi%2Fpycashier%2Fjson
[ghcrio-shield]: https://img.shields.io/badge/ghcr.io-24292f?&logo=github&logoColor=white.svg
[ghcrio-url]: https://github.com/brocklab/pycashier/pkgs/container/pycashier
[forks-shield]: https://img.shields.io/github/forks/brocklab/pycashier.svg
[forks-url]: https://github.com/brocklab/pycashier/network/members
[stars-shield]: https://img.shields.io/github/stars/brocklab/pycashier.svg
[stars-url]: https://github.com/brocklab/pycashier/stargazers
[issues-shield]: https://img.shields.io/github/issues/brocklab/pycashier.svg
[issues-url]: https://github.com/brocklab/pycashier/issues
[license-shield]: https://img.shields.io/github/license/brocklab/pycashier.svg
[license-url]: https://github.com/brocklab/pycashier/blob/main/LICENSE
